@@ -8,9 +8,9 @@
  * memorandum "A Kernel Model for Precision Timekeeping" by Dave Mills,
  * revised 31 January 1996. That document updates RFC1589.
  *
- * This program has been updated to use the new PPS API (draft-05, 1999-08-17)
+ * This program has been updated to use the new PPS API v1 from RFC 2783
  *
- * Copyright (c) 1996 - 1999 by Ulrich Windl
+ * Copyright (c) 1996 - 2000 by Ulrich Windl
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -26,7 +26,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- * $Id: enable_pps.c,v 1.36 1999/10/29 22:09:22 windl Exp $
+ * $Id: enable_pps.c,v 1.37 2000/03/11 16:45:58 windl Exp $
  */
 #include	<unistd.h>
 #include	<stdlib.h>
@@ -84,7 +84,7 @@
 #define	BITS_OFF(v, b)			((v) & ~(b))
 #define	BITS_ON(v, b)			((v) | (b))
 
-static	const char	id[] = "$Id: enable_pps.c,v 1.36 1999/10/29 22:09:22 windl Exp $";
+static	const char	id[] = "$Id: enable_pps.c,v 1.37 2000/03/11 16:45:58 windl Exp $";
 
 #define	BIT(n)	(1UL << (n))
 #define OPT_MONITOR		BIT(0)	/* perform monitor loop */
@@ -691,6 +691,17 @@ int	main(int argc, char *argv[])
 	       );
 	uname(&un);
 	printf(". Now running %s %s)\n", un.sysname, un.release);
+	if ( time_pps_create(fd, &ppshandle) )
+	{
+		perror("time_pps_create()");
+		return(1);
+	}
+	if ( time_pps_getcap(ppshandle, &parm.mode) )
+	{
+		perror("time_pps_getcap()");
+		return(1);
+	}
+	printf("PPS API capabilities are 0x%x\n", parm.mode);
 	parm.mode = PPS_TSFMT_TSPEC;	/* set default flags */
 	while ( (ch = getopt(argc, argv, "CE:eFJjkMNOo:P:St:")) != -1 )
 	{
@@ -804,8 +815,6 @@ int	main(int argc, char *argv[])
 	}
 
 	ioctl(fd, TIOCMBIC, &stat);	/* power-on DCF77 receiver */
-	if ( time_pps_create(fd, &ppshandle) )
-		perror("time_pps_create()");
 	switch ( trigger )
 	{
 	case 'A':
@@ -851,7 +860,8 @@ int	main(int argc, char *argv[])
 			else
 			{
 				fprintf(stderr,
-					"kernel consumer set (edge %#04x)\n",
+					"PPS API kernel consumer HARDPPS bound"
+					" to edge %#04x\n",
 					kc_edge);
 			}
 		}
